package com.hungraim.ltc.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ltc.dao.*;
import com.hungraim.ltc.pojo.entity.eval.*;
import com.hungraim.ltc.pojo.vo.assessment.TaskDistributionVO;
import com.hungraim.ltc.pojo.vo.assessment.TaskGroupVO;
import com.hungraim.ltc.pojo.vo.assessment.TaskReportVO;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.util.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.Date;
import java.util.List;

/**
 * @author czz
 */
@Service
public class TaskServiceImpl implements TaskService {

    @Autowired
    private TaskMapper taskMapper;
    @Autowired
    private AprEmpMapper aprEmpMapper;
    @Autowired
    private AprReportMapper aprReportMapper;
    @Autowired
    private TaskEmpMapper taskEmpMapper;
    @Autowired
    private AprPeronInfoMapper peronInfoMapper;
    @Autowired
    private TaskPushMapper taskPushMapper;

    @Override
    public IPage<TaskDistributionVO> taskDistributionList(String organId, String provincial, String city,
                                                          String street, String realName, String certiCode, String taskName, String taskTel,
                                                          String daysRemaining, String status, String isReturn, String area,
                                                          int pageNum, int pageSize) {
        List<String> organIds = null;
        if (StrUtil.isNotBlank(organId)) {
            organIds = Arrays.asList(organId.split(","));
        }
        return taskMapper.taskDistributionList(new Page<>(pageNum, pageSize), organIds, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, status, isReturn, area);
    }

    @Override
    public List<TaskReportVO> taskReportList(String name, String certiCode, String tel) {
        return taskMapper.taskReportList(name, certiCode, tel);
    }

    @Override
    public List<ChAprEmp> aprEmpList(Integer organId) {
        QueryWrapper<ChAprEmp> queryWrapper = new QueryWrapper<ChAprEmp>();
        queryWrapper.eq("IS_LOCK", 0);
        if (organId != null) {
            queryWrapper.eq("apr_organ_id", organId);
        }
        return aprEmpMapper.selectList(queryWrapper);
    }

    @Override
    public void addReport(Integer taskId, Integer person1, Integer person2, Integer person3, Integer disableLevelId, String polNo, String remark) {
        ChAprReport report = new ChAprReport();
        report.setTaskId(taskId);
        report.setEffTime(new Date());
        report.setRemark(remark);
        report.setDisableLevelId(disableLevelId);
        report.setPolNo(polNo);
        report.setStatus(0);
        aprReportMapper.insert(report);
        if (person1 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFCD(new Date());
            peronInfoMapper.insert(personInfo);
        }
        if (person2 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFCD(new Date());
            peronInfoMapper.insert(personInfo);
        }
        if (person3 != null) {
            ChAprPersonInfo personInfo = new ChAprPersonInfo();
            personInfo.setReportId(report.getReportId());
            personInfo.setEmpId(person1);
            personInfo.setFCD(new Date());
            peronInfoMapper.insert(personInfo);
        }
    }

    @Override
    public void updateReport(Integer reportId, Integer person1, Integer person2, Integer person3, Integer disableLevelId, String polNo, String remark) {
        //update鉴定报告
        ChAprReport chAprReport = aprReportMapper.selectById(reportId);
        chAprReport.setDisableLevelId(disableLevelId);
        chAprReport.setPolNo(polNo);
        chAprReport.setRemark(remark);
        aprReportMapper.updateById(chAprReport);
        //修改鉴定报告人员(有就update,没有就insert)
        List<ChAprPersonInfo> personInfos = peronInfoMapper.selectList(new QueryWrapper<ChAprPersonInfo>().eq("report_id", reportId));
        if (person1 != null) {
            if (personInfos.size() >= 1) {
                ChAprPersonInfo personInfo = personInfos.get(0);
                personInfo.setEmpId(person1);
                peronInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person1);
                personInfo.setFCD(new Date());
                peronInfoMapper.insert(personInfo);
            }
        }
        if (person2 != null) {
            if (personInfos.size() >= 2) {
                ChAprPersonInfo personInfo = personInfos.get(0);
                personInfo.setEmpId(person2);
                peronInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person2);
                personInfo.setFCD(new Date());
                peronInfoMapper.insert(personInfo);
            }
        }
        if (person3 != null) {
            if (personInfos.size() >= 3) {
                ChAprPersonInfo personInfo = personInfos.get(0);
                personInfo.setEmpId(person3);
                peronInfoMapper.updateById(personInfo);
            } else {
                ChAprPersonInfo personInfo = new ChAprPersonInfo();
                personInfo.setReportId(chAprReport.getReportId());
                personInfo.setEmpId(person3);
                personInfo.setFCD(new Date());
                peronInfoMapper.insert(personInfo);
            }
        }
    }

    @Override
    public Result<Object> allotTask(String taskId, Integer empId) {
        ChAprEmp chAprEmp = aprEmpMapper.selectById(empId);
        if (chAprEmp == null || chAprEmp.getGroupLeader() == null || chAprEmp.getGroupLeader() != 0) {
            //不是组长
            return Result.failed("评定人员必须是组长!");
        }
        String[] taskIds = taskId.split(",");
        for (String id : taskIds) {
            ChAprTask task = taskMapper.selectById(id);
            if (task == null) {
                return Result.failed("无效的taskId!");
            }
            task.setAprEmpId(empId);
            int count = taskMapper.updateById(task);
            if (count != 1) {
                return Result.failed("修改失败!");
            }
        }
        return Result.success();
    }

    @Override
    public List<TaskGroupVO> taskGroupList(String name, String certiCode, String tel) {
        return taskMapper.taskGroupList(name, certiCode, tel);
    }

    @Override
    public Result<Object> taskGroup(Integer pushId, Integer status) {
        ChAprTaskPush chAprTaskPush = taskPushMapper.selectById(pushId);
        if (chAprTaskPush == null) {
            return Result.failed("不存在的分组!");
        }
        chAprTaskPush.setStatus(status.shortValue());
        taskPushMapper.updateById(chAprTaskPush);
        return Result.success();
    }
}